kBootNumberKey constant
String
const kBootNumberKey
Detail-map key for the boot number an entry belongs to.
Implementation
static const kBootNumberKey = 'b';
Detail-map key for the boot number an entry belongs to.
static const kBootNumberKey = 'b';