transf<R extends Object> method

Dependency<R> transf<R extends Object>()

Returns a new Dependency instance where the current _value is cast to type R, while retaining the existing metadata.

Implementation

Dependency<R> transf<R extends Object>() => passNewValue(_value.transf());