groupEntity property
The type group to which the Dependency belongs. This enables dependencies of the same type to coexist in the DI container as long as they are assigned to different groups.
Implementation
final Entity groupEntity;
The type group to which the Dependency belongs. This enables dependencies of the same type to coexist in the DI container as long as they are assigned to different groups.
final Entity groupEntity;