preemptivetypeEntity property
An explicit type key for this dependency. When not DefaultEntity, this overrides the runtime type of the wrapped value as the registry key.
Implementation
final Entity preemptivetypeEntity;
An explicit type key for this dependency. When not DefaultEntity, this overrides the runtime type of the wrapped value as the registry key.
final Entity preemptivetypeEntity;